@@ -77,7 +77,8 @@ def filed(key,inquire=[]):
         'RepeatInspectionName': zx.search().getRepeatInspectionName,
         'agentDeployIp':ip.date().getAentHostIp,
         'http_port':CreateTestPort.Port().httpport,
-        'syslog_port':CreateTestPort.Port().syslogPort
+        'syslog_port':CreateTestPort.Port().syslogPort,
+        'FutureTime': ParaDateFiledServer().getFutureTime
     }
 
     switcher = SERVICE_KPI_
